# Screenshot Tests

## Local dev server

Run:

```bash
npm start
```

Then open http://localhost:8080/ in your browser.

Source files are automatically recompiled when they change.

## Writing tests

**Goal**: Cover of every line of CSS generated by our Sass. This includes all CSS selectors.

Guidelines:

1.  Keep HTML files _small_ and _focused_. This makes it easier to review diffs.

2.  Each page should target a single logical "variant" of a component. For example:
    - One "block" CSS class (e.g., `mdc-button`)
    - One "modifier" CSS class (e.g., `mdc-button--dense`)
    - One Sass mixin (e.g., `mdc-button-ink-color`)

3.  File structure:

        /test/screenshot
            /mdc-foo
                /classes
                    - baseline.html
                    - dense.html
                    - ...
                /mixins
                    - custom.scss
                    - fill-color.html
                    - filled-accessible.html
                    - ink-color.html
                    - ...

4.  Do not test _combinations_ of mixins and modifier classes unless:
    1. It's necessary to prevent a regression; or
    2. We explicitly support the combination, and the implementation is likely to have bugs (e.g., `mdc-button--dense` and `mdc-button-stroke-width` both set `line-height`)

## Example test page

![localhost_8080_mdc-button_classes_baseline html](https://user-images.githubusercontent.com/409245/38001695-05c55d10-31e3-11e8-9f35-91e3ea82f566.png)
